@@ -122,15 +122,15 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Create a new map canvas with the specified unique \a name.
-     * \since QGIS 3.0
      * \see closeMapCanvas()
+     * \since QGIS 3.0
      */
     virtual QgsMapCanvas *createNewMapCanvas( const QString &name ) = 0;
 
     /**
      * Closes the additional map canvas with matching \a name.
-     * \since QGIS 3.0
      * \see createNewMapCanvas()
+     * \since QGIS 3.0
      */
     virtual void closeMapCanvas( const QString &name ) = 0;
 
@@ -141,15 +141,15 @@ class GUI_EXPORT QgisInterface : public QObject
     virtual QSize iconSize( bool dockedToolbar = false ) const = 0;
 
     /**
-     * Return vector layers in edit mode
+     * Returns vector layers in edit mode
      * \param modified whether to return only layers that have been modified
      * \returns list of layers in legend order, or empty list */
     virtual QList<QgsMapLayer *> editableLayers( bool modified = false ) const = 0;
 
-    //! Get pointer to the active layer (layer selected in the legend)
+    //! Returns a pointer to the active layer (layer selected in the legend)
     virtual QgsMapLayer *activeLayer() = 0;
 
-    //! Return a pointer to the map canvas
+    //! Returns a pointer to the map canvas
     virtual QgsMapCanvas *mapCanvas() = 0;
 
     /**
@@ -159,10 +159,10 @@ class GUI_EXPORT QgisInterface : public QObject
      */
     virtual QgsLayerTreeMapCanvasBridge *layerTreeCanvasBridge() = 0;
 
-    //! Return a pointer to the main window (instance of QgisApp in case of QGIS)
+    //! Returns a pointer to the main window (instance of QgisApp in case of QGIS)
     virtual QWidget *mainWindow() = 0;
 
-    //! Return the message bar of the main app
+    //! Returns the message bar of the main app
     virtual QgsMessageBar *messageBar() = 0;
 
     /**
@@ -172,10 +172,10 @@ class GUI_EXPORT QgisInterface : public QObject
     virtual QList<QgsLayoutDesignerInterface *> openLayoutDesigners() = 0;
 
 
-    //! Return changeable options built from settings and/or defaults
+    //! Returns changeable options built from settings and/or defaults
     virtual QMap<QString, QVariant> defaultStyleSheetOptions() = 0;
 
-    //! Get reference font for initial qApp (may not be same as QgisApp)
+    //! Returns a reference font for initial qApp (may not be same as QgisApp)
     virtual QFont defaultStyleSheetFont() = 0;
 
     /**
@@ -184,50 +184,171 @@ class GUI_EXPORT QgisInterface : public QObject
      */
     virtual QgsAdvancedDigitizingDockWidget *cadDockWidget() = 0;
 
-    /**
+    /*
      * Accessors for inserting items into menus and toolbars.
      * An item can be inserted before any existing action.
      */
 
-    // Menus
+    /**
+     * Returns a reference to the main window "Project" menu.
+     */
     virtual QMenu *projectMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Edit" menu.
+     */
     virtual QMenu *editMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "View" menu.
+     */
     virtual QMenu *viewMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Layer" menu.
+     */
     virtual QMenu *layerMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Create New Layer" menu.
+     */
     virtual QMenu *newLayerMenu() = 0;
-    //! \since QGIS 2.5
+
+    /**
+     * Returns a reference to the main window "Add Layer" menu.
+     * \since QGIS 2.5
+     */
     virtual QMenu *addLayerMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Settings" menu.
+     */
     virtual QMenu *settingsMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Plugin" menu.
+     */
     virtual QMenu *pluginMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Raster" menu.
+     */
     virtual QMenu *rasterMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Database" menu.
+     */
     virtual QMenu *databaseMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Vector" menu.
+     */
     virtual QMenu *vectorMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Web" menu.
+     */
     virtual QMenu *webMenu() = 0;
+
+    /**
+     * Returns a reference to the right most standard menu, which is
+     * usually the last menu item before the "Help" menu.
+     *
+     * This can be used to insert additional top-level menus into
+     * their correct position BEFORE the help menu.
+     */
     virtual QMenu *firstRightStandardMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Window" menu.
+     */
     virtual QMenu *windowMenu() = 0;
+
+    /**
+     * Returns a reference to the main window "Help" menu.
+     */
     virtual QMenu *helpMenu() = 0;
 
     // ToolBars
+
+    /**
+     * Returns a reference to the main window "File" toolbar.
+     */
     virtual QToolBar *fileToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Layer" toolbar.
+     */
     virtual QToolBar *layerToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Map Navigation" toolbar.
+     */
     virtual QToolBar *mapNavToolToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Digitize" toolbar.
+     */
     virtual QToolBar *digitizeToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Advanced Digitizing" toolbar.
+     */
     virtual QToolBar *advancedDigitizeToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Shape Digitizing" toolbar.
+     * \since QGIS 3.0
+     */
     virtual QToolBar *shapeDigitizeToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Attributes" toolbar.
+     */
     virtual QToolBar *attributesToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Plugin" toolbar.
+     */
     virtual QToolBar *pluginToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Help" toolbar.
+     */
     virtual QToolBar *helpToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Raster" toolbar.
+     */
     virtual QToolBar *rasterToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Vector" toolbar.
+     */
     virtual QToolBar *vectorToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Database" toolbar.
+     */
     virtual QToolBar *databaseToolBar() = 0;
+
+    /**
+     * Returns a reference to the main window "Web" toolbar.
+     */
     virtual QToolBar *webToolBar() = 0;
 
     // Project menu actions
+    //! Returns the native New Project action.
     virtual QAction *actionNewProject() = 0;
+    //! Returns the Open Project action.
     virtual QAction *actionOpenProject() = 0;
+    //! Returns the native Save Project action.
     virtual QAction *actionSaveProject() = 0;
+    //! Returns the native Save Project As action.
     virtual QAction *actionSaveProjectAs() = 0;
+    //! Returns the native Save Map as Image action.
     virtual QAction *actionSaveMapAsImage() = 0;
+    //! Returns the native Project Properties action.
     virtual QAction *actionProjectProperties() = 0;
 
     //! Create new print layout action
@@ -235,70 +356,86 @@ class GUI_EXPORT QgisInterface : public QObject
 
     //! Show layout manager action
     virtual QAction *actionShowLayoutManager() = 0;
+    //! Returns the Exit QGIS action.
     virtual QAction *actionExit() = 0;
 
     // Edit menu actions
+
+    //! Returns the native Cut Features action.
     virtual QAction *actionCutFeatures() = 0;
+    //! Returns the native Copy Features action.
     virtual QAction *actionCopyFeatures() = 0;
+    //! Returns the native Paste Features action.
     virtual QAction *actionPasteFeatures() = 0;
+    //! Returns the native Add Feature action.
     virtual QAction *actionAddFeature() = 0;
+    //! Returns the native Delete Selected Features action.
     virtual QAction *actionDeleteSelected() = 0;
+    //! Returns the native Move Features action.
     virtual QAction *actionMoveFeature() = 0;
+    //! Returns the native Split Features action.
     virtual QAction *actionSplitFeatures() = 0;
+    //! Returns the native Split Parts action.
     virtual QAction *actionSplitParts() = 0;
+    //! Returns the native Add Ring action.
     virtual QAction *actionAddRing() = 0;
+    //! Returns the native Add Part action.
     virtual QAction *actionAddPart() = 0;
+    //! Returns the native Simplify/Smooth Features action.
     virtual QAction *actionSimplifyFeature() = 0;
+    //! Returns the native Delete Ring action.
     virtual QAction *actionDeleteRing() = 0;
+    //! Returns the native Delete Part action.
     virtual QAction *actionDeletePart() = 0;
+    //! Returns the native Vertex Tool action.
     virtual QAction *actionVertexTool() = 0;
 
     // View menu actions
-    //! Get access to the native pan action. Call trigger() on it to set the default pan map tool.
+    //! Returns the native pan action. Call trigger() on it to set the default pan map tool.
     virtual QAction *actionPan() = 0;
-    //! Get access to the native pan to selected action. Call trigger() on it to pan the map canvas to the selection.
+    //! Returns the native pan to selected action. Call trigger() on it to pan the map canvas to the selection.
     virtual QAction *actionPanToSelected() = 0;
-    //! Get access to the native zoom in action. Call trigger() on it to set the default zoom in map tool.
+    //! Returns the native zoom in action. Call trigger() on it to set the default zoom in map tool.
     virtual QAction *actionZoomIn() = 0;
-    //! Get access to the native zoom out action. Call trigger() on it to set the default zoom out map tool.
+    //! Returns the native zoom out action. Call trigger() on it to set the default zoom out map tool.
     virtual QAction *actionZoomOut() = 0;
-    //! Get access to the native select action. Call trigger() on it to set the default select map tool.
+    //! Returns the native select action. Call trigger() on it to set the default select map tool.
     virtual QAction *actionSelect() = 0;
-    //! Get access to the native select rectangle action. Call trigger() on it to set the default select rectangle map tool.
+    //! Returns the native select rectangle action. Call trigger() on it to set the default select rectangle map tool.
     virtual QAction *actionSelectRectangle() = 0;
-    //! Get access to the native select polygon action. Call trigger() on it to set the default select polygon map tool.
+    //! Returns the native select polygon action. Call trigger() on it to set the default select polygon map tool.
     virtual QAction *actionSelectPolygon() = 0;
-    //! Get access to the native select freehand action. Call trigger() on it to set the default select freehand map tool.
+    //! Returns the native select freehand action. Call trigger() on it to set the default select freehand map tool.
     virtual QAction *actionSelectFreehand() = 0;
-    //! Get access to the native select radius action. Call trigger() on it to set the default select radius map tool.
+    //! Returns the native select radius action. Call trigger() on it to set the default select radius map tool.
     virtual QAction *actionSelectRadius() = 0;
-    //! Get access to the native identify action. Call trigger() on it to set the default identify map tool.
+    //! Returns the native identify action. Call trigger() on it to set the default identify map tool.
     virtual QAction *actionIdentify() = 0;
-    //! Get access to the native run action feature action. Call trigger() on it to set the default run feature action map tool.
+    //! Returns the native run action feature action. Call trigger() on it to set the default run feature action map tool.
     virtual QAction *actionFeatureAction() = 0;
-    //! Get access to the native measure action. Call trigger() on it to set the default measure map tool.
+    //! Returns the native measure action. Call trigger() on it to set the default measure map tool.
     virtual QAction *actionMeasure() = 0;
-    //! Get access to the native measure area action. Call trigger() on it to set the default measure area map tool.
+    //! Returns the native measure area action. Call trigger() on it to set the default measure area map tool.
     virtual QAction *actionMeasureArea() = 0;
-    //! Get access to the native zoom full extent action. Call trigger() on it to zoom to the full extent.
+    //! Returns the native zoom full extent action. Call trigger() on it to zoom to the full extent.
     virtual QAction *actionZoomFullExtent() = 0;
-    //! Get access to the native zoom to layer action. Call trigger() on it to zoom to the active layer.
+    //! Returns the native zoom to layer action. Call trigger() on it to zoom to the active layer.
     virtual QAction *actionZoomToLayer() = 0;
-    //! Get access to the native zoom to selected action. Call trigger() on it to zoom to the current selection.
+    //! Returns the native zoom to selected action. Call trigger() on it to zoom to the current selection.
     virtual QAction *actionZoomToSelected() = 0;
-    //! Get access to the native zoom last action. Call trigger() on it to zoom to last.
+    //! Returns the native zoom last action. Call trigger() on it to zoom to last.
     virtual QAction *actionZoomLast() = 0;
-    //! Get access to the native zoom next action. Call trigger() on it to zoom to next.
+    //! Returns the native zoom next action. Call trigger() on it to zoom to next.
     virtual QAction *actionZoomNext() = 0;
-    //! Get access to the native zoom resolution (100%) action. Call trigger() on it to zoom to actual size.
+    //! Returns the native zoom resolution (100%) action. Call trigger() on it to zoom to actual size.
     virtual QAction *actionZoomActualSize() = 0;
-    //! Get access to the native map tips action. Call trigger() on it to toggle map tips.
+    //! Returns the native map tips action. Call trigger() on it to toggle map tips.
     virtual QAction *actionMapTips() = 0;
-    //! Get access to the native new bookmark action. Call trigger() on it to open the new bookmark dialog.
+    //! Returns the native new bookmark action. Call trigger() on it to open the new bookmark dialog.
     virtual QAction *actionNewBookmark() = 0;
-    //! Get access to the native show bookmarks action. Call trigger() on it to open the bookmarks dialog.
+    //! Returns the native show bookmarks action. Call trigger() on it to open the bookmarks dialog.
     virtual QAction *actionShowBookmarks() = 0;
-    //! Get access to the native draw action.
+    //! Returns the native draw action.
     virtual QAction *actionDraw() = 0;
 
     // Layer menu actions
@@ -307,9 +444,9 @@ class GUI_EXPORT QgisInterface : public QObject
     virtual QAction *actionAddRasterLayer() = 0;
     virtual QAction *actionAddPgLayer() = 0;
     virtual QAction *actionAddWmsLayer() = 0;
-    //! Get access to the native Add ArcGIS FeatureServer action.
+    //! Returns the native Add ArcGIS FeatureServer action.
     virtual QAction *actionAddAfsLayer() = 0;
-    //! Get access to the native Add ArcGIS MapServer action.
+    //! Returns the native Add ArcGIS MapServer action.
     virtual QAction *actionAddAmsLayer() = 0;
     virtual QAction *actionCopyLayerStyle() = 0;
     virtual QAction *actionPasteLayerStyle() = 0;
@@ -373,7 +510,7 @@ class GUI_EXPORT QgisInterface : public QObject
      */
     virtual QgsVectorLayerTools *vectorLayerTools() = 0;
 
-    //! Get timeout for timed messages: default of 5 seconds
+    //! Returns the timeout for timed messages: default of 5 seconds
     virtual int messageTimeout() = 0;
 
     /**
@@ -632,63 +769,69 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * Register a new tab in the vector layer properties dialog.
-     * \since QGIS 2.16
      * \note Ownership of the factory is not transferred, and the factory must
      *       be unregistered when plugin is unloaded.
-     * \see unregisterMapLayerPropertiesFactory() */
+     * \see unregisterMapLayerConfigWidgetFactory()
+     * \since QGIS 2.16
+     */
     virtual void registerMapLayerConfigWidgetFactory( QgsMapLayerConfigWidgetFactory *factory ) = 0;
 
     /**
      * Unregister a previously registered tab in the vector layer properties dialog.
+     * \see registerMapLayerConfigWidgetFactory()
      * \since QGIS 2.16
-     * \see registerMapLayerPropertiesFactory()
     */
     virtual void unregisterMapLayerConfigWidgetFactory( QgsMapLayerConfigWidgetFactory *factory ) = 0;
 
     /**
      * Register a new tab in the options dialog.
-     * \since QGIS 3.0
      * \note Ownership of the factory is not transferred, and the factory must
      *       be unregistered when plugin is unloaded.
-     * \see unregisterOptionsWidgetFactory() */
+     * \see unregisterOptionsWidgetFactory()
+     * \since QGIS 3.0
+     */
     virtual void registerOptionsWidgetFactory( QgsOptionsWidgetFactory *factory ) = 0;
 
     /**
      * Unregister a previously registered tab in the options dialog.
-     * \since QGIS 3.0
      * \see registerOptionsWidgetFactory()
+     * \since QGIS 3.0
     */
     virtual void unregisterOptionsWidgetFactory( QgsOptionsWidgetFactory *factory ) = 0;
 
     /**
      * Register a new custom drop handler.
-     * \since QGIS 3.0
      * \note Ownership of the factory is not transferred, and the factory must
      *       be unregistered when plugin is unloaded.
-     * \see unregisterCustomDropHandler() */
+     * \see unregisterCustomDropHandler()
+     * \since QGIS 3.0
+     */
     virtual void registerCustomDropHandler( QgsCustomDropHandler *handler ) = 0;
 
     /**
      * Unregister a previously registered custom drop handler.
+     * \see registerCustomDropHandler()
      * \since QGIS 3.0
-     * \see registerCustomDropHandler() */
+     */
     virtual void unregisterCustomDropHandler( QgsCustomDropHandler *handler ) = 0;
 
     /**
      * Register a new custom drop \a handler for layout windows.
-     * \since QGIS 3.0
      * \note Ownership of the factory is not transferred, and the factory must
      *       be unregistered when plugin is unloaded.
-     * \see unregisterCustomLayoutDropHandler() */
+     * \see unregisterCustomLayoutDropHandler()
+     * \since QGIS 3.0
+     */
     virtual void registerCustomLayoutDropHandler( QgsLayoutCustomDropHandler *handler ) = 0;
 
     /**
      * Unregister a previously registered custom drop \a handler for layout windows.
+     * \see registerCustomLayoutDropHandler()
      * \since QGIS 3.0
-     * \see registerCustomLayoutDropHandler() */
+     */
     virtual void unregisterCustomLayoutDropHandler( QgsLayoutCustomDropHandler *handler ) = 0;
 
-    // @todo is this deprecated in favour of QgsContextHelp?
+    // TODO is this deprecated in favour of QgsContextHelp?
 
     /**
      * Open a url in the users browser. By default the QGIS doc directory is used
@@ -697,7 +840,7 @@ class GUI_EXPORT QgisInterface : public QObject
      * \param url URL to open
      * \param useQgisDocDirectory If true, the URL will be formed by concatenating
      * url to the QGIS documentation directory path (prefix/share/doc)
-     * \deprecated
+     * \deprecated Use QDesktopServices instead
      */
 #ifndef Q_MOC_RUN
     Q_DECL_DEPRECATED
@@ -759,6 +902,15 @@ class GUI_EXPORT QgisInterface : public QObject
      */
     virtual void deregisterLocatorFilter( QgsLocatorFilter *filter ) = 0;
 
+    /**
+     * Invalidate results from the locator filter.
+     *
+     * This might be useful if the configuration of the filter changed without going through main application settings.
+     *
+     * \since QGIS 3.2
+     */
+    virtual void invalidateLocatorResults() = 0;
+
     /**
       * Checks available datum transforms and ask user if several are available and none
       * is chosen. Dialog is shown only if global option is set accordingly.
@@ -784,25 +936,25 @@ class GUI_EXPORT QgisInterface : public QObject
 
     /**
      * This signal is emitted when a new layout \a designer has been opened.
-     * \since QGIS 3.0
      * \see layoutDesignerWillBeClosed()
+     * \since QGIS 3.0
      */
     void layoutDesignerOpened( QgsLayoutDesignerInterface *designer );
 
     /**
      * This signal is emitted before a layout \a designer is going to be closed
      * and deleted.
-     * \since QGIS 3.0
      * \see layoutDesignerClosed()
      * \see layoutDesignerOpened()
+     * \since QGIS 3.0
      */
     void layoutDesignerWillBeClosed( QgsLayoutDesignerInterface *designer );
 
     /**
      * This signal is emitted after a layout designer window is closed.
-     * \since QGIS 3.0
      * \see layoutDesignerWillBeClosed()
      * \see layoutDesignerOpened()
+     * \since QGIS 3.0
      */
     void layoutDesignerClosed();
 
