@@ -27,7 +27,7 @@ __copyright__ = '(C) 2015, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 import os
 from qgis.core import QgsProcessingException
@@ -100,11 +100,19 @@ def variableOutput(alg, layers, parameters, context, nocats=True):
         if not isinstance(typeList, list):
             continue
 
-        fileName = alg.parameterAsOutputLayer(parameters, outputName, context)
-        grassName = '{}{}'.format(typeList[0], alg.uniqueSuffix)
-        alg.exportVectorLayer(
-            grassName, fileName, typeList[1], typeList[2],
-            typeList[3])
+        file_name = alg.parameterAsOutputLayer(parameters, outputName, context)
+
+        src_layer = typeList[0]
+        output_type = typeList[1]
+        output_layer_number = typeList[2]
+        no_cats = typeList[3]
+
+        grass_name = '{}{}'.format(src_layer, alg.uniqueSuffix)
+        alg.exportVectorLayer(grassName=grass_name,
+                              fileName=file_name,
+                              layer=output_layer_number,
+                              nocats=no_cats,
+                              dataType=output_type)
 
 
 def processOutputs(alg, parameters, context, feedback):
