@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 import os
 from collections import OrderedDict
@@ -98,7 +98,7 @@ class Heatmap(QgisAlgorithm):
                                                               [QgsProcessing.TypeVectorPoint]))
 
         self.addParameter(QgsProcessingParameterDistance(self.RADIUS,
-                                                         self.tr('Radius (layer units)'),
+                                                         self.tr('Radius'),
                                                          100.0, self.INPUT, False, 0.0, 9999999999.99))
 
         radius_field_param = QgsProcessingParameterField(self.RADIUS_FIELD,
