@@ -21,7 +21,7 @@ __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 #############################################################################
 #
@@ -397,7 +397,7 @@ class Site(object):
             return False
         elif self.x < other.x:
             return True
-        elif self.x > other.x:
+        else:
             return False
 
     def distance(self, other):
@@ -512,7 +512,7 @@ class Halfedge(object):
             return False
         elif self.vertex.x < other.vertex.x:
             return True
-        elif self.vertex.x > other.vertex.x:
+        else:
             return False
 
     def leftreg(self, default):
@@ -905,4 +905,4 @@ def cmp(a, b):
 
     In python 2 cmp() was a built in function but in python 3 is gone.
     """
-    return (a > b) - (a < b)
+    return (b < a) - (a < b)
